Attribute Macros

Prepares the function to allow it to be set as an after hook, see the implementation for more information about this macro’s behaviour.

Prepares the function to be used to autocomplete command arguments.

Prepares the function to allow it to be set as a before hook, see the implementation for more information about this macro’s behaviour.

Converts an async-compatible function into a builder and modifies function’s body to parse all required arguments, for further information about the behaviour of this macro, see the implementation.

Converts an async function into a normal function returning a Pin<Box<dyn Future<Output = _> + '_>>

Derive Macros